pygeodesy.etm.Etm

Package pygeodesy :: Module etm :: Class Etm |
[frames] | no frames]

# Class Etm

       object --+
                |
     named._Named --+
                    |
     named._NamedBase --+
                        |
    utmupsBase.UtmUpsBase --+
                            |
                      utm.Utm --+
                                |
                               Etm

Exact Transverse Mercator (ETM) coordinate, a sub-class of Utm, a Universal Transverse Mercator (UTM) coordinate using the ExactTransverseMercator projection for highest accuracy.

Note: Conversion of (geodetic) lat- and longitudes to/from Etm coordinates is 3-4 times slower than to/from Utm.

See Also: Karney's Detailed Description.

Instance Methods
__init__(self, zone=31, hemisphere=`'``N``'`, easting=166022, northing=0, band='', datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, falsed=True, gamma=None, scale=None, **name_convergence) New Etm Exact Transverse Mercator coordinate, raising ETMErrors. |
parse(self, strETM, **name) Parse a string to a similar Etm instance. |
parseETM(self, strETM) DEPRECATED, use method Etm.parse. |
toLatLon(self, LatLon=None, unfalse=True, **unused) Convert this ETM coordinate to an (ellipsoidal) geodetic point. |
toUtm(self) Copy this ETM to a UTM coordinate. |
Inherited from `utm.Utm`: `__eq__`, `__repr__`, `__str__`, `parseUTM`, `toEtm`, `toRepr`, `toStr`, `toUps` Inherited from `utmupsBase.UtmUpsBase`: `eastingnorthing2`, `latFootPoint`, `phiFootPoint`, `to2en`, `toEpsg`, `toMgrs` Inherited from `named._NamedBase`: `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| exactTM Class `property` with a `.name` attribute.
Inherited from `utm.Utm`: `band`, `falsed2`, `pole`, `zone` Inherited from `utmupsBase.UtmUpsBase`: `convergence`, `datum`, `easting`, `eastingnorthing`, `falsed`, `gamma`, `hemisphere`, `northing`, `scale`, `scale0` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, zone=31, hemisphere=`'``N``'`, easting=166022, northing=0, band='', datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, falsed=True, gamma=None, scale=None, **name_convergence) (Constructor) |
New Etm Exact Transverse Mercator coordinate, raising ETMErrors. Arguments: `zone` - Longitudinal UTM zone (`int`, 1..60) or zone with/-out latitudinal Band letter (`str`, '1C'|..|'60X'). `hemisphere` - Northern or southern hemisphere (`str`, `'N[orth]'` or `'S[outh]'`). `easting` - Easting, see `falsed` (`meter`). `northing` - Northing, see `falsed` (`meter`). `band` - Optional, latitudinal band (`str`, 'C'|..|'X', no 'I'|'O'). `datum` - Optional, this coordinate's datum (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `falsed` - If `True`, both `easting` and `northing` are falsed (`bool`). `gamma` - Optional meridian convergence, bearing off grid North, clockwise from true North to save (`degrees`) or `None`. `scale` - Optional grid scale factor to save (`scalar`) or `None`. `name_convergence` - Optional `name=NN` (`str`) and DEPRECATED keyword argument `convergence=None`, use `gamma`. Raises: `TypeError` - Invalid or near-spherical `datum`. `UTMError` - Invalid `zone`, `hemishere`, `easting`, `northing`, `band`, `convergence` or `scale`. Overrides: object.__init__

### parse (self, strETM, **name) |
Parse a string to a similar Etm instance. Arguments: `strETM` - The ETM coordinate (`str`), see function parseETM5. `name` - Optional `name=NN` (`str`), overriding this name. Returns: The instance (Etm). Raises: `ETMError` - Invalid `strETM`. Overrides: utm.Utm.parse See Also: Function pygeodesy.parseUPS5, pygeodesy.parseUTM5 and pygeodesy.parseUTMUPS5.

### parseETM (self, strETM) |
DEPRECATED, use method Etm.parse. Decorators: `@deprecated_method`

### toLatLon (self, LatLon=None, unfalse=True, **unused) |
Convert this ETM coordinate to an (ellipsoidal) geodetic point. Arguments: `LatLon` - Optional, ellipsoidal class to return the geodetic point (`LatLon`) or `None`. `unfalse` - Unfalse `easting` and `northing` if `falsed` (`bool`). Returns: This ETM coordinate as (`LatLon`) or if `LatLon is None`, a LatLonDatum5Tuple`(lat, lon, datum, gamma, scale)`. Raises: `ETMError` - This ETM coordinate's `exacTM` and this `datum` are not compatible or no convergence transforming to lat-/longitude. `TypeError` - Invalid or non-ellipsoidal `LatLon`. Overrides: utm.Utm.toLatLon

### toUtm (self) |
Copy this ETM to a UTM coordinate. Arguments: `zone` - New UTM zone (`int`). `eps` - Optional convergence limit, EPS or above (`float`), see method Utm.toLatLon. `falsed` - If `True`, fFalse both easting and northing (`bool`). Returns: The UTM coordinate (Utm). Overrides: utm.Utm.toUtm

Property Details

### exactTM Class `property` with a `.name` attribute. Get method: exactTM(self) - Get the ETM projection (ExactTransverseMercator). Set method: exactTM(self, exactTM) - Set the ETM projection (ExactTransverseMercator).